@@ -51,7 +51,6 @@
 # include <saml/saml2/metadata/Metadata.h>
 # include <saml/saml2/metadata/MetadataProvider.h>
 # include <xmltooling/XMLToolingConfig.h>
-# include <xmltooling/util/DateTime.h>
 # include <xmltooling/util/ParserPool.h>
 # include <xmltooling/util/XMLHelper.h>
 # include <xercesc/framework/MemBufInputSource.hpp>
@@ -121,7 +120,7 @@ namespace shibsp {
     #pragma warning( pop )
 #endif
 
-    Handler* SHIBSP_DLLLOCAL ExternalAuthFactory(const pair<const DOMElement*,const char*>& p)
+    Handler* SHIBSP_DLLLOCAL ExternalAuthFactory(const pair<const DOMElement*,const char*>& p, bool)
     {
         return new ExternalAuth(p.first, p.second);
     }
@@ -164,9 +163,14 @@ namespace {
 };
 
 ExternalAuth::ExternalAuth(const DOMElement* e, const char* appId)
-    : SecuredHandler(e, Category::getInstance(SHIBSP_LOGCAT ".ExternalAuth"), "acl", "127.0.0.1 ::1")
+    : SecuredHandler(e, Category::getInstance(SHIBSP_LOGCAT ".Handler.ExternalAuth"), "acl", "127.0.0.1 ::1")
 {
-    setAddress("run::ExternalAuth");
+    pair<bool,const char*> prop = getString("Location");
+    if (!prop.first)
+        throw ConfigurationException("ExternalAuth handler requires Location property.");
+    string address(appId);
+    address += prop.second;
+    setAddress(address.c_str());
 }
 
 pair<bool,long> ExternalAuth::run(SPRequest& request, bool isHandler) const
@@ -199,11 +203,11 @@ pair<bool,long> ExternalAuth::run(SPRequest& request, bool isHandler) const
             headers.push_back("Cookie");
             DDF out,in = wrap(request, &headers);
             DDFJanitor jin(in), jout(out);
-            out=request.getServiceProvider().getListenerService()->send(in);
+            out = send(request, in);
             return unwrap(request, out);
         }
     }
-    catch (std::exception& ex) {
+    catch (const std::exception& ex) {
         m_log.error("error while processing request: %s", ex.what());
         istringstream msg("External Authentication Failed");
         return make_pair(true, request.sendResponse(msg, HTTPResponse::XMLTOOLING_HTTP_STATUS_ERROR));
@@ -235,7 +239,7 @@ void ExternalAuth::receive(DDF& in, ostream& out)
     try {
         processMessage(*app, *req, *resp, in, &ret);
     }
-    catch (std::exception& ex) {
+    catch (const std::exception& ex) {
         m_log.error("raising exception: %s", ex.what());
         throw;
     }
@@ -255,7 +259,7 @@ pair<bool,long> ExternalAuth::processMessage(
     scoped_ptr<TransactionLog::Event> event;
     LoginEvent* login_event = nullptr;
     if (SPConfig::getConfig().isEnabled(SPConfig::Logging)) {
-        event.reset(SPConfig::getConfig().EventManager.newPlugin(LOGIN_EVENT, nullptr));
+        event.reset(SPConfig::getConfig().EventManager.newPlugin(LOGIN_EVENT, nullptr, false));
         login_event = dynamic_cast<LoginEvent*>(event.get());
         if (login_event)
             login_event->m_app = &application;
@@ -274,7 +278,7 @@ pair<bool,long> ExternalAuth::processMessage(
         Wrapper4InputSource dsrc(&src, false);
         DOMDocument* doc = XMLToolingConfig::getConfig().getParser().parse(dsrc);
         XercesJanitor<DOMDocument> janitor(doc);
-        auto_ptr<XMLObject> xmlObject(XMLObjectBuilder::buildOneFromElement(doc->getDocumentElement(), true));
+        scoped_ptr<XMLObject> xmlObject(XMLObjectBuilder::buildOneFromElement(doc->getDocumentElement(), true));
         janitor.release();
 
         saml2::Assertion* token = dynamic_cast<saml2::Assertion*>(xmlObject.get());
@@ -442,11 +446,11 @@ pair<bool,long> ExternalAuth::processMessage(
             }
         }
 
-        scoped_ptr<DateTime> authn_instant;
+        scoped_ptr<XMLDateTime> authn_instant;
         param = httpRequest.getParameter("AuthnInstant");
         if (param && *param) {
             auto_ptr_XMLCh d(param);
-            authn_instant.reset(new DateTime(d.get()));
+            authn_instant.reset(new XMLDateTime(d.get()));
             authn_instant->parseDateTime();
         }
 
@@ -490,7 +494,7 @@ pair<bool,long> ExternalAuth::processMessage(
                     }
                 }
             }
-            catch (std::exception&) {
+            catch (const std::exception&) {
                 for_each(resolvedAttributes.begin(), resolvedAttributes.end(), xmltooling::cleanup<shibsp::Attribute>());
                 throw;
             }
@@ -562,7 +566,7 @@ pair<bool,long> ExternalAuth::processMessage(
     try {
         recoverRelayState(application, httpRequest, httpResponse, target);
     }
-    catch (std::exception& ex) {
+    catch (const std::exception& ex) {
         m_log.error("error recovering relay state: %s", ex.what());
         target.erase();
     }
@@ -592,8 +596,10 @@ pair<bool,long> ExternalAuth::processMessage(
             }
         }
         os << " ]";
-        if (!target.empty())
-            os << ", \"RelayState\": "; json_safe(os, target.c_str());
+        if (!target.empty()) {
+            os << ", \"RelayState\": ";
+            json_safe(os, target.c_str());
+        }
         os << " }";
     }
     else {
@@ -700,7 +706,7 @@ ResolutionContext* ExternalAuth::resolveAttributes(
                             *id = mprefix.second + *id;
                     }
                 }
-                catch (std::exception& ex) {
+                catch (const std::exception& ex) {
                     m_log.error("caught exception extracting attributes: %s", ex.what());
                 }
             }
@@ -712,7 +718,7 @@ ResolutionContext* ExternalAuth::resolveAttributes(
             try {
                 extractor->extractAttributes(application, request, issuer, *nameid, resolvedAttributes);
             }
-            catch (std::exception& ex) {
+            catch (const std::exception& ex) {
                 m_log.error("caught exception extracting attributes: %s", ex.what());
             }
         }
@@ -721,7 +727,7 @@ ResolutionContext* ExternalAuth::resolveAttributes(
             try {
                 extractor->extractAttributes(application, request, issuer, *statement, resolvedAttributes);
             }
-            catch (std::exception& ex) {
+            catch (const std::exception& ex) {
                 m_log.error("caught exception extracting attributes: %s", ex.what());
             }
         }
@@ -732,7 +738,7 @@ ResolutionContext* ExternalAuth::resolveAttributes(
                 try {
                     extractor->extractAttributes(application, request, issuer, *t, resolvedAttributes);
                 }
-                catch (std::exception& ex) {
+                catch (const std::exception& ex) {
                     m_log.error("caught exception extracting attributes: %s", ex.what());
                 }
             }
@@ -745,7 +751,7 @@ ResolutionContext* ExternalAuth::resolveAttributes(
             try {
                 filter->filterAttributes(fc, resolvedAttributes);
             }
-            catch (std::exception& ex) {
+            catch (const std::exception& ex) {
                 m_log.error("caught exception filtering attributes: %s", ex.what());
                 m_log.error("dumping extracted attributes due to filtering exception");
                 for_each(resolvedAttributes.begin(), resolvedAttributes.end(), xmltooling::cleanup<shibsp::Attribute>());
@@ -785,7 +791,7 @@ ResolutionContext* ExternalAuth::resolveAttributes(
             return ctx.release();
         }
     }
-    catch (std::exception& ex) {
+    catch (const std::exception& ex) {
         m_log.error("attribute resolution failed: %s", ex.what());
     }
 
@@ -793,7 +799,7 @@ ResolutionContext* ExternalAuth::resolveAttributes(
         try {
             return new DummyContext(resolvedAttributes);
         }
-        catch (bad_alloc&) {
+        catch (const bad_alloc&) {
             for_each(resolvedAttributes.begin(), resolvedAttributes.end(), xmltooling::cleanup<shibsp::Attribute>());
         }
     }
@@ -805,7 +811,7 @@ LoginEvent* ExternalAuth::newLoginEvent(const Application& application, const HT
     if (!SPConfig::getConfig().isEnabled(SPConfig::Logging))
         return nullptr;
     try {
-        auto_ptr<TransactionLog::Event> event(SPConfig::getConfig().EventManager.newPlugin(LOGIN_EVENT, nullptr));
+        auto_ptr<TransactionLog::Event> event(SPConfig::getConfig().EventManager.newPlugin(LOGIN_EVENT, nullptr, false));
         LoginEvent* login_event = dynamic_cast<LoginEvent*>(event.get());
         if (login_event) {
             login_event->m_request = &request;
@@ -818,10 +824,10 @@ LoginEvent* ExternalAuth::newLoginEvent(const Application& application, const HT
             m_log.warn("unable to audit event, log event object was of an incorrect type");
         }
     }
-    catch (std::exception& ex) {
+    catch (const std::exception& ex) {
         m_log.warn("exception auditing event: %s", ex.what());
     }
     return nullptr;
 }
 
-#endif
\ No newline at end of file
+#endif
