@@ -34,7 +34,7 @@
 #include "util/SPConstants.h"
 
 #ifndef SHIBSP_LITE
-# include "SessionCacheEx.h"
+# include "SessionCache.h"
 # include "security/SecurityPolicy.h"
 # include "security/SecurityPolicyProvider.h"
 # include "metadata/MetadataProviderCriteria.h"
@@ -73,7 +73,7 @@ namespace shibsp {
     class SHIBSP_DLLLOCAL SAML2Logout : public AbstractHandler, public LogoutHandler
     {
     public:
-        SAML2Logout(const DOMElement* e, const char* appId);
+        SAML2Logout(const DOMElement* e, const char* appId, bool deprecationSupport=true);
         virtual ~SAML2Logout() {}
 
         void receive(DDF& in, ostream& out);
@@ -103,7 +103,7 @@ namespace shibsp {
         }
 
     private:
-        pair<bool,long> doRequest(const Application& application, const HTTPRequest& httpRequest, HTTPResponse& httpResponse) const;
+        pair<bool,long> doRequest(const Application& application, HTTPRequest& httpRequest, HTTPResponse& httpResponse) const;
 
 #ifndef SHIBSP_LITE
         pair<bool,long> sendResponse(
@@ -139,13 +139,13 @@ namespace shibsp {
     #pragma warning( pop )
 #endif
 
-    Handler* SHIBSP_DLLLOCAL SAML2LogoutFactory(const pair<const DOMElement*,const char*>& p)
+    Handler* SHIBSP_DLLLOCAL SAML2LogoutFactory(const pair<const DOMElement*,const char*>& p, bool deprecationSupport)
     {
-        return new SAML2Logout(p.first, p.second);
+        return new SAML2Logout(p.first, p.second, deprecationSupport);
     }
 };
 
-SAML2Logout::SAML2Logout(const DOMElement* e, const char* appId)
+SAML2Logout::SAML2Logout(const DOMElement* e, const char* appId, bool deprecationSupport)
     : AbstractHandler(e, Category::getInstance(SHIBSP_LOGCAT ".Logout.SAML2"))
 #ifndef SHIBSP_LITE
         ,m_protocol(samlconstants::SAML20P_NS)
@@ -161,17 +161,13 @@ SAML2Logout::SAML2Logout(const DOMElement* e, const char* appId)
         SAMLConfig& conf = SAMLConfig::getConfig();
 
         // Handle incoming binding.
-        m_decoder.reset(
-            conf.MessageDecoderManager.newPlugin(
-                getString("Binding").second, pair<const DOMElement*,const XMLCh*>(e,shibspconstants::SHIB2SPCONFIG_NS)
-                )
-            );
+        m_decoder.reset(conf.MessageDecoderManager.newPlugin(getString("Binding").second, e, deprecationSupport));
         m_decoder->setArtifactResolver(SPConfig::getConfig().getArtifactResolver());
 
         if (m_decoder->isUserAgentPresent()) {
             // Handle front-channel binding setup.
             string dupBindings;
-            pair<bool,const char*> outgoing = getString("outgoingBindings", m_configNS.get());
+            pair<bool,const char*> outgoing = getString("outgoingBindings", shibspconstants::ASCII_SHIBSPCONFIG_NS);
             if (outgoing.first) {
                 dupBindings = outgoing.second;
                 trim(dupBindings);
@@ -185,9 +181,7 @@ SAML2Logout::SAML2Logout(const DOMElement* e, const char* appId)
             split(m_bindings, dupBindings, is_space(), algorithm::token_compress_on);
             for (vector<string>::const_iterator b = m_bindings.begin(); b != m_bindings.end(); ++b) {
                 try {
-                    boost::shared_ptr<MessageEncoder> encoder(
-                        conf.MessageEncoderManager.newPlugin(*b, pair<const DOMElement*,const XMLCh*>(e,shibspconstants::SHIB2SPCONFIG_NS))
-                        );
+                    boost::shared_ptr<MessageEncoder> encoder(conf.MessageEncoderManager.newPlugin(*b, e, deprecationSupport));
                     if (encoder->isUserAgentPresent() && XMLString::equals(getProtocolFamily(), encoder->getProtocolFamily())) {
                         m_encoders[*b] = encoder;
                         m_log.debug("supporting outgoing binding (%s)", b->c_str());
@@ -196,16 +190,14 @@ SAML2Logout::SAML2Logout(const DOMElement* e, const char* appId)
                         m_log.warn("skipping outgoing binding (%s), not a SAML 2.0 front-channel mechanism", b->c_str());
                     }
                 }
-                catch (std::exception& ex) {
+                catch (const std::exception& ex) {
                     m_log.error("error building MessageEncoder: %s", ex.what());
                 }
             }
         }
         else {
             pair<bool,const char*> b = getString("Binding");
-            boost::shared_ptr<MessageEncoder> encoder(
-                conf.MessageEncoderManager.newPlugin(b.second, pair<const DOMElement*,const XMLCh*>(e,shibspconstants::SHIB2SPCONFIG_NS))
-                );
+            boost::shared_ptr<MessageEncoder> encoder(conf.MessageEncoderManager.newPlugin(b.second, e, deprecationSupport));
             m_encoders[b.second] = encoder;
         }
     }
@@ -235,7 +227,7 @@ pair<bool,long> SAML2Logout::run(SPRequest& request, bool isHandler) const
         headers.push_back("User-Agent");
         DDF out,in = wrap(request, &headers, true);
         DDFJanitor jin(in), jout(out);
-        out=request.getServiceProvider().getListenerService()->send(in);
+        out = send(request, in);
         return unwrap(request, out);
     }
 }
@@ -266,12 +258,11 @@ void SAML2Logout::receive(DDF& in, ostream& out)
     out << ret;
 }
 
-pair<bool,long> SAML2Logout::doRequest(const Application& application, const HTTPRequest& request, HTTPResponse& response) const
+pair<bool,long> SAML2Logout::doRequest(const Application& application, HTTPRequest& request, HTTPResponse& response) const
 {
 #ifndef SHIBSP_LITE
     // First capture the active session ID.
     SessionCache* cache = application.getServiceProvider().getSessionCache();
-    SessionCacheEx* cacheex = dynamic_cast<SessionCacheEx*>(cache);
     string session_id = cache->active(application, request);
 
     scoped_ptr<LogoutEvent> logout_event(newLogoutEvent(application, &request));
@@ -295,7 +286,7 @@ pair<bool,long> SAML2Logout::doRequest(const Application& application, const HTT
                 cache->remove(application, request, &response);
                 worked2 = true;
             }
-            catch (std::exception& ex) {
+            catch (const std::exception& ex) {
                 m_log.error("error removing session (%s): %s", session_id.c_str(), ex.what());
             }
         }
@@ -355,7 +346,7 @@ pair<bool,long> SAML2Logout::doRequest(const Application& application, const HTT
     // If we get here, it's an external protocol message to decode.
 
     // Locate policy key.
-    pair<bool,const char*> policyId = getString("policyId", m_configNS.get());  // may be namespace-qualified inside handler element
+    pair<bool,const char*> policyId = getString("policyId", shibspconstants::ASCII_SHIBSPCONFIG_NS);  // may be namespace-qualified inside handler element
     if (!policyId.first)
         policyId = getString("policyId");   // try unqualified
     if (!policyId.first)
@@ -415,7 +406,7 @@ pair<bool,long> SAML2Logout::doRequest(const Application& application, const HTT
                             );
                         nameid = dynamic_cast<NameID*>(decryptedID.get());
                     }
-                    catch (std::exception& ex) {
+                    catch (const std::exception& ex) {
                         m_log.error(ex.what());
                     }
                 }
@@ -470,24 +461,17 @@ pair<bool,long> SAML2Logout::doRequest(const Application& application, const HTT
         // Now we perform "logout" by finding the matching sessions.
         vector<string> sessions;
         try {
-            if (cacheex) {
-                time_t expires = logoutRequest->getNotOnOrAfter() ? logoutRequest->getNotOnOrAfterEpoch() : 0;
-                cacheex->logout(application, entity, *nameid, &indexes, expires, sessions);
-                m_log.debug("session cache returned %d sessions bound to NameID in logout request", sessions.size());
+            time_t expires = logoutRequest->getNotOnOrAfter() ? logoutRequest->getNotOnOrAfterEpoch() : 0;
+            cache->logout(application, entity, *nameid, &indexes, expires, sessions);
+            m_log.debug("session cache returned %d sessions bound to NameID in logout request", sessions.size());
 
-                // Now we actually terminate everything except for the active session,
-                // if this is front-channel, for notification purposes.
-                for (vector<string>::const_iterator sit = sessions.begin(); sit != sessions.end(); ++sit)
-                    if (*sit != session_id)
-                        cacheex->remove(application, sit->c_str()); // using the ID-based removal operation
-            }
-            else {
-                m_log.warn("session cache does not support extended API, can't implement indirect logout of sessions");
-                if (!session_id.empty())
-                    sessions.push_back(session_id);
-            }
+            // Now we actually terminate everything except for the active session,
+            // if this is front-channel, for notification purposes.
+            for (vector<string>::const_iterator sit = sessions.begin(); sit != sessions.end(); ++sit)
+                if (*sit != session_id)
+                    cache->remove(application, sit->c_str()); // using the ID-based removal operation
         }
-        catch (std::exception& ex) {
+        catch (const std::exception& ex) {
             m_log.error("error while logging out matching sessions: %s", ex.what());
             if (logout_event) {
                 logout_event->m_nameID = nameid;
@@ -578,7 +562,7 @@ pair<bool,long> SAML2Logout::doRequest(const Application& application, const HTT
         try {
             checkError(logoutResponse, policy->getIssuerMetadata()); // throws if Status doesn't look good...
         }
-        catch (std::exception& ex) {
+        catch (const std::exception& ex) {
             if (logout_event) {
                 logout_event->m_exception = &ex;
                 application.getServiceProvider().getTransactionLog()->write(*logout_event);
